@@ -6,23 +6,39 @@ from django.http import (
     HttpResponseNotAllowed,
 )
 from django.shortcuts import redirect
+from coffee.contrib.parse.functions import get_pagination
 
-from coffee.util.decorators import has_sufficient_params
-from coffee.util.functions import (
-    get_delete_button_html,
-    render_model_form_html,
+from coffee.contrib.decorators import has_sufficient_params
+from coffee.contrib.render.functions import (
+    render_model_form,
+    render_model_table,
 )
 
 
 @staff_member_required
 @has_sufficient_params
-def get_model_form(request):
-    app_name = request.GET.get("app_name")
-    model_name = request.GET.get("model_name")
-    pk = request.GET.get("pk")
+def get_model_list(request, app_name=None, model_name=None, pk=None):
+    page_size = int(request.GET.get("page_size", 15))
+    page = int(request.GET.get("page", 1))
 
+    offset = (page - 1) * page_size
+
+    cls = apps.get_model(app_name, model_name)
+    queryset = cls.objects.all()[offset : offset + page_size]
+
+    pagination = get_pagination(request, cls, page_size, page)
+
+    html = render_model_table(cls, queryset, pagination)
+
+    return HttpResponse(html)
+
+
+@staff_member_required
+@has_sufficient_params
+def get_model_form(request, app_name=None, model_name=None, pk=None):
     instance = None
 
+    cls = None
     if pk:
         try:
             cls = apps.get_model(app_name, model_name)
@@ -31,23 +47,14 @@ def get_model_form(request):
             exception = f"pk '{pk}' for '{app_name}.{model_name}' not found"
             return HttpResponseBadRequest(exception)
 
-    html = "<div class='Wrapper'>\n"
-    html += "<div class='Header'>\n"
-    if instance:
-        html += get_delete_button_html(request, app_name, model_name) % instance.pk
-    html += "</div>"
-    html += render_model_form_html(request, app_name, model_name, instance)
-    html += "</div>"
+    html = render_model_form(request, app_name, model_name, instance)
 
     return HttpResponse(html)
 
 
 @staff_member_required
 @has_sufficient_params
-def post_model_form(request):
-    app_name = request.GET.get("app_name")
-    model_name = request.GET.get("model_name")
-
+def post_model_form(request, app_name=None, model_name=None, pk=None):
     cls = apps.get_model(app_name, model_name)
     pk_field = cls._meta.pk.name
 
@@ -80,10 +87,7 @@ def post_model_form(request):
 
 @staff_member_required
 @has_sufficient_params
-def delete_model_instance(request, pk=None):
-    app_name = request.GET.get("app_name")
-    model_name = request.GET.get("model_name")
-
+def delete_model_instance(request, app_name=None, model_name=None, pk=None):
     cls = apps.get_model(app_name, model_name)
 
     if request.method != "POST":
